@@ -17,10 +17,6 @@
 
 int main(int argc,char **argv)
 {
-    // Fixes blurry icons with fractional scaling
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-#endif
     QApplication app(argc, argv);
 
     KLocalizedString::setApplicationDomain("kspaceduel");
@@ -34,20 +30,22 @@ int main(int argc,char **argv)
             QStringLiteral("https://apps.kde.org/kspaceduel") );
     aboutData.addAuthor(i18n("Andreas Zehender"),i18n("Original Program"), QStringLiteral("az@azweb.de"));
     aboutData.addAuthor(i18n("Branan Riley"),i18n("SVG Renderer"), QStringLiteral("branan@gmail.com"));
-    QCommandLineParser parser;
+
     KAboutData::setApplicationData(aboutData);
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kspaceduel")));
+
     KCrash::initialize();
+
+    QCommandLineParser parser;
     aboutData.setupCommandLine(&parser);
     parser.process(app);
     aboutData.processCommandLine(&parser);
+
     KDBusService service;
 
     MyTopLevelWidget *top = new MyTopLevelWidget;
     top->show();
     top->start();
 
-    app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kspaceduel")));
-
     return app.exec();
 }
-
